@@ -18,8 +18,16 @@ test_that("descriptions() function works as expected.", {
   
   expect_equal(length(lst), 2)
   
+  expect_error(descriptions(df1) <- list(mpd = "Hello"))
+  
+  
+  #str(df1) 
+  
+  descriptions(df1)
+  
+  descriptions(df1) <- NULL
+  expect_equal(length(descriptions(df1)), 0)
   
-  format(df1) 
   
 })
 
