@@ -18,7 +18,16 @@ test_that("widths() function works as expected.", {
   expect_equal(length(lst), 2)
   
   
-  format(df1) 
+  
+  expect_error(widths(df1) <- list(mpd = 12))
+  
+  
+  fdata(df1) 
+  
+  widths(df1)
+  
+  widths(df1) <- NULL
+  expect_equal(length(widths(df1)), 0)
   
   
 })
